==> vbox-kernel-module-src-5.2.14.tar.xz: vboxdrv/generic/RTAssertShouldPanic-generic.c <==
/* $Id: RTAssertShouldPanic-generic.cpp 118412 2017-10-17 14:26:02Z bird $ */
/** @file
 * IPRT - Assertions, generic RTAssertShouldPanic.
 */

/*
 * Copyright (C) 2006-2017 Oracle Corporation
 *
 * This file is part of VirtualBox Open Source Edition (OSE), as
 * available from http://www.virtualbox.org. This file is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License (GPL) as published by the Free Software
 * Foundation, in version 2 as it comes in the "COPYING" file of the
 * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
 *
 * The contents of this file may alternatively be used under the terms
 * of the Common Development and Distribution License Version 1.0
 * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
 * VirtualBox OSE distribution, in which case the provisions of the
 * CDDL are applicable instead of those of the GPL.
 *
 * You may elect to license modified versions of this file under the
 * terms and conditions of either the GPL or the CDDL or both.
 */


/*********************************************************************************************************************************
*   Header Files                                                                                                                 *
*********************************************************************************************************************************/
#include <iprt/assert.h>
#include "internal/iprt.h"


RTDECL(bool) RTAssertShouldPanic(void)
{
#if 0 /* Enable this to not panic on assertions. (Make sure this code is used!) */
    return false;
#else
    return RTAssertMayPanic();
#endif
}
RT_EXPORT_SYMBOL(RTAssertShouldPanic);

==> vbox-kernel-module-src-6.0.0.tar.xz: vboxdrv/generic/RTAssertShouldPanic-generic.c <==
/* $Id: RTAssertShouldPanic-generic.cpp 119940 2017-12-26 14:41:01Z bird $ */
/** @file
 * IPRT - Assertions, generic RTAssertShouldPanic.
 */

/*
 * Copyright (C) 2006-2017 Oracle Corporation
 *
 * This file is part of VirtualBox Open Source Edition (OSE), as
 * available from http://www.virtualbox.org. This file is free software;
 * you can redistribute it and/or modify it under the terms of the GNU
 * General Public License (GPL) as published by the Free Software
 * Foundation, in version 2 as it comes in the "COPYING" file of the
 * VirtualBox OSE distribution. VirtualBox OSE is distributed in the
 * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
 *
 * The contents of this file may alternatively be used under the terms
 * of the Common Development and Distribution License Version 1.0
 * (CDDL) only, as it comes in the "COPYING.CDDL" file of the
 * VirtualBox OSE distribution, in which case the provisions of the
 * CDDL are applicable instead of those of the GPL.
 *
 * You may elect to license modified versions of this file under the
 * terms and conditions of either the GPL or the CDDL or both.
 */


/*********************************************************************************************************************************
*   Header Files                                                                                                                 *
*********************************************************************************************************************************/
#include <iprt/assert.h>
#include "internal/iprt.h"

#ifdef IN_RING
# if 0
#  include <iprt/asm.h>
#  include <iprt/asm-amd64-x86.h>
# endif
#endif


RTDECL(bool) RTAssertShouldPanic(void)
{
#ifdef IN_RING0
# if 0 /* this can be useful when debugging guests. */
    ASMIntDisable();
    ASMHalt();
# endif
#endif
#if 0 /* Enable this to not panic on assertions. (Make sure this code is used!) */
    return false;
#else
    return RTAssertMayPanic();
#endif
}
RT_EXPORT_SYMBOL(RTAssertShouldPanic);
